@@ -17,10 +17,10 @@ static void *HBAudioDefaultsContext = &HBAudioDefaultsContext;
 
 @property (nonatomic, readonly, strong) HBLanguagesSelection *languagesList;
 
-@property (unsafe_unretained) IBOutlet HBLanguageArrayController *tableController;
-@property (unsafe_unretained) IBOutlet NSButton *showAllButton;
+@property (nonatomic, unsafe_unretained) IBOutlet HBLanguageArrayController *tableController;
+@property (nonatomic, unsafe_unretained) IBOutlet NSButton *showAllButton;
 
-@property (unsafe_unretained) IBOutlet NSArrayController *tracksController;
+@property (nonatomic, unsafe_unretained) IBOutlet NSArrayController *tracksController;
 
 @end
 
@@ -97,8 +97,7 @@ static void *HBAudioDefaultsContext = &HBAudioDefaultsContext;
 
 - (IBAction)openUserGuide:(id)sender
 {
-    [[NSWorkspace sharedWorkspace] openURL:[NSURL
-                                            URLWithString:@"https://handbrake.fr/docs/en/1.2.0/advanced/audio-subtitle-defaults.html"]];
+    [[NSWorkspace sharedWorkspace] openURL:[HBUtilities.documentationURL URLByAppendingPathComponent:@"advanced/audio-subtitle-defaults.html"]];
 }
 
 - (void)dealloc
