@@ -18,16 +18,16 @@
 #import "HBPicture+UIAdditions.h"
 #import "HBFilters+UIAdditions.h"
 
+#import "HBAudioTransformers.h"
 #import "HBLocalizationUtilities.h"
 
-#include "hb.h"
+#include "handbrake/handbrake.h"
 
 // Text Styles
-static NSMutableParagraphStyle *ps;
 static NSDictionary            *detailAttr;
 static NSDictionary            *detailBoldAttr;
-static NSDictionary            *titleAttr;
 static NSDictionary            *shortHeightAttr;
+static HBMixdownTransformer    *mixdownTransformer;
 
 @implementation HBJob (UIAdditions)
 
@@ -51,9 +51,9 @@ static NSDictionary            *shortHeightAttr;
     return [NSSet setWithObjects:@"container", @"video.encoder", nil];
 }
 
-- (NSArray *)angles
+- (NSArray<NSString *> *)angles
 {
-    NSMutableArray *angles = [NSMutableArray array];
+    NSMutableArray<NSString *> *angles = [NSMutableArray array];
     for (int i = 1; i <= self.title.angles; i++)
     {
         [angles addObject:[NSString stringWithFormat: @"%d", i]];
@@ -61,9 +61,9 @@ static NSDictionary            *shortHeightAttr;
     return angles;
 }
 
-- (NSArray *)containers
+- (NSArray<NSString *> *)containers
 {
-    NSMutableArray *containers = [NSMutableArray array];
+    NSMutableArray<NSString *> *containers = [NSMutableArray array];
 
     for (const hb_container_t *container = hb_container_get_next(NULL);
          container != NULL;
@@ -78,6 +78,10 @@ static NSDictionary            *shortHeightAttr;
         {
             title = HBKitLocalizedString(@"MKV File", @"HBJob -> Format display name");
         }
+        else if (container->format & HB_MUX_MASK_WEBM)
+        {
+            title = HBKitLocalizedString(@"WebM File", @"HBJob -> Format display name");
+        }
         else
         {
             title = @(container->name);
@@ -92,37 +96,37 @@ static NSDictionary            *shortHeightAttr;
 
 - (void)initStyles
 {
-    if (!ps)
+    if (!detailAttr)
     {
         // Attributes
-        ps = [[NSParagraphStyle defaultParagraphStyle] mutableCopy];
+        NSMutableParagraphStyle *ps = [NSParagraphStyle.defaultParagraphStyle mutableCopy];
         ps.headIndent = 88.0;
         ps.paragraphSpacing = 1.0;
-        ps.tabStops = @[[[NSTextTab alloc] initWithType:
-                          NSRightTabStopType location: 88],
-                         [[NSTextTab alloc] initWithType:
-                          NSLeftTabStopType location: 90]];
+        ps.tabStops = @[[[NSTextTab alloc] initWithType:NSRightTabStopType location:88],
+                        [[NSTextTab alloc] initWithType:NSLeftTabStopType location:90]];
 
-        detailAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:[NSFont smallSystemFontSize]],
-                        NSParagraphStyleAttributeName: ps};
+        detailAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:NSFont.smallSystemFontSize],
+                       NSParagraphStyleAttributeName: ps,
+                       NSForegroundColorAttributeName: NSColor.labelColor};
 
-        detailBoldAttr = @{NSFontAttributeName: [NSFont boldSystemFontOfSize:[NSFont smallSystemFontSize]],
-                            NSParagraphStyleAttributeName: ps};
+        detailBoldAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:NSFont.smallSystemFontSize],
+                           NSParagraphStyleAttributeName: ps,
+                           NSForegroundColorAttributeName: NSColor.labelColor};
 
-        titleAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:[NSFont systemFontSize]],
-                       NSParagraphStyleAttributeName: ps};
-
-        shortHeightAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:2.0]};
+        shortHeightAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:6.0]};
     }
 }
 
-- (NSAttributedString *)titleAttributedDescription
+- (void)initTransformers
 {
-    NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
-
-    // Job name
-    [attrString appendString:self.description withAttributes:titleAttr];
+    if (!mixdownTransformer)
+    {
+        mixdownTransformer = [[HBMixdownTransformer alloc] init];
+    }
+}
 
+- (NSString *)rangeDescription
+{
     // Range type
     NSString *startStopString = @"";
     if (self.range.type == HBRangeTypeChapters)
@@ -160,16 +164,25 @@ static NSDictionary            *shortHeightAttr;
 
     if (passesString.length)
     {
-        [attrString appendString:[NSString stringWithFormat:HBKitLocalizedString(@" (Title %d, %@, %@) ▸ %@\n", @"Title description"),
-                                  self.titleIdx, startStopString, passesString, self.outputFileName]
-                  withAttributes:detailAttr];
+        return [NSString stringWithFormat:HBKitLocalizedString(@"Title %d, %@, %@", @"Title description"),
+                self.titleIdx, startStopString, passesString];
     }
     else
     {
-        [attrString appendString:[NSString stringWithFormat:HBKitLocalizedString(@" (Title %d, %@) ▸ %@\n", @"Title description"),
-                                  self.titleIdx, startStopString, self.outputFileName]
-                  withAttributes:detailAttr];
+        return [NSString stringWithFormat:HBKitLocalizedString(@"Title %d, %@", @"Title description"),
+                self.titleIdx, startStopString];
     }
+}
+
+- (NSAttributedString *)rangeAttributedDescription
+{
+    NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
+
+    [attrString appendString:@"\t" withAttributes:detailAttr];
+    [attrString appendString:HBKitLocalizedString(@"Range:", @"Range description") withAttributes:detailBoldAttr];
+    [attrString appendString:@" \t" withAttributes:detailAttr];
+    [attrString appendString:self.rangeDescription withAttributes:detailAttr];
+    [attrString appendString:@"\n" withAttributes:detailAttr];
 
     return attrString;
 }
@@ -228,6 +241,19 @@ static NSDictionary            *shortHeightAttr;
     return attrString;
 }
 
+- (NSAttributedString *)sourceAttributedDescription
+{
+    NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
+
+    [attrString appendString:@"\t"                          withAttributes:detailAttr];
+    [attrString appendString:HBKitLocalizedString(@"Source:", @"Source description") withAttributes:detailBoldAttr];
+    [attrString appendString:@" \t"                         withAttributes:detailAttr];
+    [attrString appendString:self.fileURL.path              withAttributes:detailAttr];
+    [attrString appendString:@"\n"                          withAttributes:detailAttr];
+
+    return attrString;
+}
+
 - (NSAttributedString *)destinationAttributedDescription
 {
     NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
@@ -301,9 +327,19 @@ static NSDictionary            *shortHeightAttr;
     }
 
     // Deblock
-    if (filters.deblock > 0)
+    if (![filters.deblock isEqualToString:@"off"])
     {
-        [summary appendFormat:@", %@ (%d)", HBKitLocalizedString(@"Deblock", @"Filters description"), filters.deblock];
+        [summary appendFormat:@", %@ (%@", HBKitLocalizedString(@"Deblock", @"Filters description"), [[[HBFilters deblockPresetDict] allKeysForObject:filters.deblock] firstObject]];
+        if (![filters.deblock isEqualToString:@"custom"])
+        {
+            [summary appendFormat:@", %@", [[[HBFilters deblockTunesDict] allKeysForObject:filters.deblockTune] firstObject]];
+        }
+        else
+        {
+            [summary appendFormat:@", %@", filters.deblockCustomString];
+        }
+
+        [summary appendString:@")"];
     }
 
     // Denoise
@@ -351,7 +387,6 @@ static NSDictionary            *shortHeightAttr;
         }
 
         [summary appendString:@")"];
-
     }
 
     // Grayscale
@@ -370,7 +405,7 @@ static NSDictionary            *shortHeightAttr;
     {
         [attrString appendString:@"\t"          withAttributes:detailAttr];
         [attrString appendString:HBKitLocalizedString(@"Filters:", @"Filters description") withAttributes:detailBoldAttr];
-        [attrString appendString:@" \t"          withAttributes:detailAttr];
+        [attrString appendString:@" \t"         withAttributes:detailAttr];
         [attrString appendString:summary        withAttributes:detailAttr];
         [attrString appendString:@"\n"          withAttributes:detailAttr];
     }
@@ -422,7 +457,7 @@ static NSDictionary            *shortHeightAttr;
     else // CRF
     {
         [videoInfo appendFormat:@", "];
-        [videoInfo appendFormat:HBKitLocalizedString(@"Constant Quality: %.2f %s", @"Video description"), self.video.quality, hb_video_quality_get_name(self.video.encoder)];
+        [videoInfo appendString:[NSString localizedStringWithFormat:HBKitLocalizedString(@"Constant Quality: %.2f %s", @"Video description"), self.video.quality, hb_video_quality_get_name(self.video.encoder)]];
     }
 
     [attrString appendString:@"\t"       withAttributes:detailAttr];
@@ -493,7 +528,7 @@ static NSDictionary            *shortHeightAttr;
         [attrString appendString:lavcInfo   withAttributes:detailAttr];
         [attrString appendString:@"\n"      withAttributes:detailAttr];
     }
-    
+
     return attrString;
 }
 
@@ -511,27 +546,29 @@ static NSDictionary            *shortHeightAttr;
         if (audioTrack.isEnabled)
         {
             NSMutableString *detailString = [NSMutableString stringWithFormat:HBKitLocalizedString(@"%@ ▸ Encoder: %@", @"Audio description"),
-                                      self.audio.sourceTracks[audioTrack.sourceTrackIdx][keyAudioTrackName],
+                                      self.audio.sourceTracks[audioTrack.sourceTrackIdx].displayName,
                                       @(hb_audio_encoder_get_name(audioTrack.encoder))];
 
-            if ((audioTrack.encoder  & HB_ACODEC_PASS_FLAG) == 0)
+            if ((audioTrack.encoder & HB_ACODEC_PASS_FLAG) == 0)
             {
+                NSString *mixdown = [mixdownTransformer transformedValue:@(audioTrack.mixdown)];
+
                 [detailString appendString:@", "];
                 [detailString appendFormat:HBKitLocalizedString(@"Mixdown: %@, Samplerate: %@, Bitrate: %d kbps", @"Audio description"),
-                                            @(hb_mixdown_get_name(audioTrack.mixdown)),
+                                            mixdown,
                                             audioTrack.sampleRate ? [NSString stringWithFormat:@"%@ khz", @(hb_audio_samplerate_get_name(audioTrack.sampleRate))] : @"Auto",
                                             audioTrack.bitRate];
 
                 if (0.0 < audioTrack.drc)
                 {
                     [detailString appendString:@", "];
-                    [detailString appendFormat:HBKitLocalizedString(@"DRC: %.2f", @"Audio description"), audioTrack.drc];
+                    [detailString appendString:[NSString localizedStringWithFormat:HBKitLocalizedString(@"DRC: %.2f", @"Audio description"), audioTrack.drc]];
                 }
 
                 if (0.0 != audioTrack.gain)
                 {
                     [detailString appendString:@", "];
-                    [detailString appendFormat:HBKitLocalizedString(@"Gain: %.2f", @"Audio description"), audioTrack.gain];
+                    [detailString appendString:[NSString localizedStringWithFormat:HBKitLocalizedString(@"Gain: %.2f", @"Audio description"), audioTrack.gain]];
                 }
             }
 
@@ -569,7 +606,7 @@ static NSDictionary            *shortHeightAttr;
             NSMutableString *detailString = [NSMutableString string];
 
             // remember that index 0 of Subtitles can contain "Foreign Audio Search
-            [detailString appendString:self.subtitles.sourceTracks[track.sourceTrackIdx][@"keySubTrackName"]];
+            [detailString appendString:self.subtitles.sourceTracks[track.sourceTrackIdx].displayName];
 
             if (track.forcedOnly)
             {
@@ -608,24 +645,47 @@ static NSDictionary            *shortHeightAttr;
 {
     NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
     [self initStyles];
+    [self initTransformers];
 
     @autoreleasepool
     {
-        [attrString appendAttributedString:[self titleAttributedDescription]];
         [attrString appendAttributedString:[self presetAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
+        [attrString appendAttributedString:[self sourceAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
+        [attrString appendAttributedString:[self destinationAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
         [attrString appendAttributedString:[self formatAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
+        [attrString appendAttributedString:[self rangeAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
         [attrString appendAttributedString:[self dimensionsAttributedDescription]];
-        [attrString appendAttributedString:[self filtersAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
+        NSAttributedString *filters = [self filtersAttributedDescription];
+        if (filters.length)
+        {
+            [attrString appendAttributedString:[self filtersAttributedDescription]];
+            [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+        }
+
         [attrString appendAttributedString:[self videoAttributedDescription]];
+        [attrString appendString:@"\n" withAttributes: shortHeightAttr];
+
         if (self.audio.countOfTracks > 1)
         {
             [attrString appendAttributedString:[self audioAttributedDescription]];
+            [attrString appendString:@"\n" withAttributes: shortHeightAttr];
         }
         if (self.subtitles.countOfTracks > 1)
         {
             [attrString appendAttributedString:[self subtitlesAttributedDescription]];
         }
-        [attrString appendAttributedString:[self destinationAttributedDescription]];
     }
 
     [attrString deleteCharactersInRange:NSMakeRange(attrString.length - 1, 1)];
@@ -666,11 +726,11 @@ static NSDictionary            *shortHeightAttr;
         }
         if (self.video.frameRateMode == 0)
         {
-            [info appendString:@" FPS PFR"];
+            [info appendString:HBKitLocalizedString(@" FPS PFR", @"HBJob -> video short description framerate")];
         }
         else
         {
-            [info appendString:@" FPS CFR"];
+            [info appendString:HBKitLocalizedString(@" FPS CFR", @"HBJob -> video short description framerate")];
         }
     }
 
@@ -692,13 +752,13 @@ static NSDictionary            *shortHeightAttr;
                 [info appendString:@(encoder)];
             }
 
-            if ((audioTrack.encoder  & HB_ACODEC_PASS_FLAG) == 0)
+            if ((audioTrack.encoder & HB_ACODEC_PASS_FLAG) == 0)
             {
-                const char *mixdown = hb_mixdown_get_name(audioTrack.mixdown);
+                NSString *mixdown = [mixdownTransformer transformedValue:@(audioTrack.mixdown)];
                 if (mixdown)
                 {
                     [info appendString:@", "];
-                    [info appendString:@(mixdown)];
+                    [info appendString:mixdown];
                 }
             }
 
@@ -743,7 +803,7 @@ static NSDictionary            *shortHeightAttr;
         if (track.isEnabled)
         {
             // remember that index 0 of Subtitles can contain "Foreign Audio Search
-            [info appendString:self.subtitles.sourceTracks[track.sourceTrackIdx][@"keySubTrackName"]];
+            [info appendString:self.subtitles.sourceTracks[track.sourceTrackIdx].displayName];
 
             if (track.burnedIn)
             {
@@ -784,6 +844,8 @@ static NSDictionary            *shortHeightAttr;
 {
     NSMutableString *info = [NSMutableString string];
 
+    [self initTransformers];
+
     [info appendString:[self videoShortDescription]];
 
     NSString *audioInfo = [self audioShortDescription];
@@ -841,7 +903,7 @@ static NSDictionary            *shortHeightAttr;
     }
 
     // Deblock
-    if (filters.deblock > 0)
+    if (![filters.deblock isEqualToString:@"off"])
     {
         [summary appendString:HBKitLocalizedString(@"Deblock", @"HBJob -> filters short description")];
         [summary appendString:@", "];
@@ -916,6 +978,10 @@ static NSDictionary            *shortHeightAttr;
     {
         return HBKitLocalizedString(@"MKV File", @"HBJob -> Format display name");
     }
+    else if (container & HB_MUX_MASK_WEBM)
+    {
+        return HBKitLocalizedString(@"WebM File", @"HBJob -> Format display name");
+    }
     else
     {
         const char *name = hb_container_get_name(container);
@@ -945,6 +1011,10 @@ static NSDictionary            *shortHeightAttr;
     {
         return @(HB_MUX_AV_MKV);
     }
+    else if ([value isEqualToString:HBKitLocalizedString(@"WebM File", @"HBJob -> Format display name")])
+    {
+        return @(HB_MUX_AV_WEBM);
+    }
 
     return @(hb_container_get_from_name([value UTF8String]));
 }
@@ -982,4 +1052,3 @@ static NSDictionary            *shortHeightAttr;
 }
 
 @end
-
