@@ -619,8 +619,6 @@ NSString * const HBQueueItemNotificationItemKey = @"HBQueueItemNotificationItemK
             [NSNotificationCenter.defaultCenter postNotificationName:HBQueueDidStartItemNotification object:self userInfo:@{HBQueueItemNotificationItemKey: nextItem,
                                                                                                                             HBQueueItemNotificationIndexesKey: indexes}];
 
-            [self updateStats];
-
             // now we can go ahead and scan the new pending queue item
             [self encodeItem:nextItem];
 
@@ -636,6 +634,8 @@ NSString * const HBQueueItemNotificationItemKey = @"HBQueueItemNotificationItemK
         }
     }
 
+    [self updateStats];
+
     [NSNotificationCenter.defaultCenter postNotificationName:HBQueueDidChangeStateNotification object:self];
 
     [self.items commit];
@@ -723,6 +723,8 @@ NSString * const HBQueueItemNotificationItemKey = @"HBQueueItemNotificationItemK
         }
     };
 
+    [item.job refreshSecurityScopedResources];
+
     // Only scan 10 previews before an encode - additional previews are
     // only useful for autocrop and static previews, which are already taken care of at this point
     [self.core scanURL:item.fileURL
