@@ -5,9 +5,13 @@
  It may be used under the terms of the GNU General Public License. */
 
 #import <Foundation/Foundation.h>
+#import "HBSecurityAccessToken.h"
 
 NS_ASSUME_NONNULL_BEGIN
 
+@interface NSURL (HBSecurityScope) <HBSecurityScope>
+@end
+
 @interface HBUtilities : NSObject
 
 /**
