@@ -9,7 +9,7 @@
 #import "HBCodingUtilities.h"
 #import "HBMutablePreset.h"
 
-#include "hb.h"
+#include "handbrake/handbrake.h"
 
 NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 
@@ -28,7 +28,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 
 @implementation HBVideo
 
-- (instancetype)initWithJob:(HBJob *)job;
+- (instancetype)initWithJob:(HBJob *)job
 {
     self = [super init];
     if (self) {
@@ -39,10 +39,12 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
         _job = job;
 
         _preset = @"medium";
-        _tune = @"";
+        _tune = @"none";
         _profile = @"auto";
         _level = @"auto";
 
+        _videoOptionExtra = @"";
+
         [self updateQualityBounds];
 
         _notificationsEnabled = YES;
@@ -202,7 +204,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 
     if (!encoderSupported)
     {
-        self.encoder = HB_VCODEC_X264;
+        self.encoder = hb_video_encoder_get_default(self.job.container);
     }
 }
 
@@ -223,13 +225,13 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
         [[self.undo prepareWithInvocationTarget:self] setTune:_tune];
     }
 
-    if (![tune isEqualToString:@"none"])
+    if (tune == nil || [tune isEqualToString:@""])
     {
-        _tune = [tune copy];
+        _tune = @"none";
     }
     else
     {
-        _tune = @"";
+        _tune = [tune copy];
     }
 
     [self postChangedNotification];
@@ -332,6 +334,11 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     if (levels.count && ![levels containsObject:self.level]) {
         self.level = levels.firstObject;
     }
+
+    if (!(self.encoder & HB_VCODEC_X264_MASK))
+    {
+        self.fastDecode = NO;
+    }
 }
 
 - (void)validateVideoOptionExtra:(int)previousEncoder
@@ -379,9 +386,9 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     return [NSSet setWithObjects:@"encoder", nil];
 }
 
-- (NSArray *)tunes
+- (NSArray<NSString *> *)tunes
 {
-    NSMutableArray *temp = [NSMutableArray array];
+    NSMutableArray<NSString *> *temp = [NSMutableArray array];
 
     [temp addObject:@"none"];
 
@@ -390,7 +397,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     for (int i = 0; tunes != NULL && tunes[i] != NULL; i++)
     {
         // we filter out "fastdecode" as we have a dedicated checkbox for it
-        if (strcasecmp(tunes[i], "fastdecode") != 0)
+        if (!(self.encoder & HB_VCODEC_X264_MASK) || strcasecmp(tunes[i], "fastdecode") != 0)
         {
             [temp addObject:@(tunes[i])];
         }
@@ -404,9 +411,9 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     return [NSSet setWithObjects:@"encoder", nil];
 }
 
-- (NSArray *)profiles
+- (NSArray<NSString *> *)profiles
 {
-    NSMutableArray *temp = [NSMutableArray array];
+    NSMutableArray<NSString *> *temp = [NSMutableArray array];
 
     const char * const *profiles = hb_video_encoder_get_profiles(self.encoder);
     for (int i = 0; profiles != NULL && profiles[i] != NULL; i++)
@@ -426,9 +433,9 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     return [NSSet setWithObjects:@"encoder", nil];
 }
 
-- (NSArray *)levels
+- (NSArray<NSString *> *)levels
 {
-    NSMutableArray *temp = [NSMutableArray array];
+    NSMutableArray<NSString *> *temp = [NSMutableArray array];
 
     const char * const *levels = hb_video_encoder_get_levels(self.encoder);
     for (int i = 0; levels != NULL && levels[i] != NULL; i++)
@@ -492,7 +499,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 
     encodeInt(_encoder);
 
-    encodeInt(_qualityType);
+    encodeInteger(_qualityType);
     encodeInt(_avgBitrate);
     encodeDouble(_quality);
 
@@ -500,7 +507,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     encodeDouble(_qualityMaxValue);
 
     encodeInt(_frameRate);
-    encodeInt(_frameRateMode);
+    encodeInteger(_frameRateMode);
 
     encodeBool(_twoPass);
     encodeBool(_turboTwoPass);
@@ -521,16 +528,15 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 
     decodeInt(_encoder);
 
-    decodeInt(_qualityType);
-    decodeInt(_avgBitrate);
+    decodeInteger(_qualityType); if (_qualityType < HBVideoQualityTypeAvgBitrate || _qualityType > HBVideoQualityTypeConstantQuality) { goto fail; }
+    decodeInt(_avgBitrate); if (_avgBitrate < 0) { goto fail; }
     decodeDouble(_quality);
 
     decodeDouble(_qualityMinValue);
     decodeDouble(_qualityMaxValue);
 
-    decodeInt(_frameRate);
-    decodeInt(_frameRateMode);
-
+    decodeInt(_frameRate); if (_frameRate < 0) { goto fail; }
+    decodeInteger(_frameRateMode); if (_frameRateMode < HBVideoFrameRateModeVFR_PFR || _frameRateMode > HBVideoFrameRateModeCFR) { goto fail; }
     decodeBool(_twoPass);
     decodeBool(_turboTwoPass);
 
@@ -572,7 +578,7 @@ fail:
 {
     NSMutableString *string = [[NSMutableString alloc] init];
 
-    if (self.tune)
+    if (self.tune && ![self.tune isEqualToString:@"none"])
     {
         [string appendString:self.tune];
     }
