@@ -217,9 +217,7 @@ namespace HandBrake.Interop.Interop
                 {
                     height = settings.Height,
                     width = settings.Width,
-                    par = settings.Anamorphic != Anamorphic.Custom && settings.Anamorphic != Anamorphic.Automatic
-                        ? new hb_rational_t { den = title.Geometry.PAR.Den, num = title.Geometry.PAR.Num }
-                        : new hb_rational_t { den = settings.PixelAspectY, num = settings.PixelAspectX }
+                    par = new hb_rational_t { den = settings.PixelAspectY, num = settings.PixelAspectX }
                 }
             };
 
@@ -470,8 +468,16 @@ namespace HandBrake.Interop.Interop
             {
                 if (this.EncodeProgress != null)
                 {
-                    TimeSpan eta = TimeSpan.FromSeconds(state.Working.ETASeconds);
-                    var progressEventArgs = new EncodeProgressEventArgs(state.Working.Progress, state.Working.Rate, state.Working.RateAvg, eta, state.Working.PassID, state.Working.Pass, state.Working.PassCount, taskState.Code);
+                    TimeSpan eta = TimeSpan.FromSeconds(state?.Working?.ETASeconds ?? 0);
+                    var progressEventArgs = new EncodeProgressEventArgs(0, 0, 0, TimeSpan.MinValue, 0, 0, 0, taskState.Code);
+                    if (taskState == TaskState.Muxing || state.Working == null)
+                    {
+                        progressEventArgs = new EncodeProgressEventArgs(100, 0, 0, TimeSpan.MinValue, 0, 0, 0, taskState.Code);
+                    }
+                    else
+                    {
+                        progressEventArgs = new EncodeProgressEventArgs(state.Working.Progress, state.Working.Rate, state.Working.RateAvg, eta, state.Working.PassID, state.Working.Pass, state.Working.PassCount, taskState.Code);
+                    }
 
                     this.EncodeProgress(this, progressEventArgs);
                 }
