@@ -197,6 +197,10 @@ namespace HandBrakeWPF.Services.Queue
                 {
                     this.queue.Add(task);
                 }
+                if (reloadedQueue.Count > 0)
+                {
+                    this.InvokeQueueChanged(EventArgs.Empty);
+                }
             }
         }
 
@@ -216,13 +220,29 @@ namespace HandBrakeWPF.Services.Queue
             return false;
         }
 
+        public void RetryJob(QueueTask task)
+        {
+            if (task == null)
+            {
+                return;
+            }
+
+            task.Status = QueueItemStatus.Waiting;
+            task.Statistics.Reset();
+            this.BackupQueue(null);
+     
+            this.InvokeQueueChanged(EventArgs.Empty);
+        }
+
         public void Clear()
         {
-            List<QueueTask> deleteList = this.queue.ToList();
+            List<QueueTask> deleteList = this.queue.Where(i => i.Status != QueueItemStatus.InProgress).ToList();
+
             foreach (QueueTask item in deleteList)
             {
                 this.queue.Remove(item);
             }
+
             this.InvokeQueueChanged(EventArgs.Empty);
         }
 
@@ -237,6 +257,7 @@ namespace HandBrakeWPF.Services.Queue
                     {
                         this.queue.Remove(item);
                     }
+
                     this.InvokeQueueChanged(EventArgs.Empty);
                 });
         }
@@ -389,6 +410,10 @@ namespace HandBrakeWPF.Services.Queue
             {
                 this.ProcessNextJob();
             }
+            else
+            {
+                this.IsProcessing = true;
+            }
         }
 
         public void Stop()
