@@ -37,7 +37,6 @@ namespace HandBrakeWPF
         public const string PreventSleep = "PreventSleep";
         public const string PauseOnLowDiskspace = "PauseOnLowDiskspace";
         public const string PauseQueueOnLowDiskspaceLevel = "LowDiskSpaceWarningLevelInBytes";
-        public const string PauseEncodeOnLowDiskspaceLevel = "LowDiskSpaceEncodePauseLevelInBytes";
         public const string RemovePunctuation = "RemovePunctuation";
         public const string ShowPresetPanel = "ShowPresetPanelOption";
         public const string ResetWhenDoneAction = "ResetWhenDoneAction";
@@ -74,5 +73,6 @@ namespace HandBrakeWPF
         public const string WhenDonePerformActionImmediately = "WhenDonePerformActionImmediately";
         public const string UseDarkTheme = "UseDarkTheme";
         public const string PreviewRotationFlip = "PreviewRotationFlip";
+        public const string AlwaysUseDefaultPath = "AlwaysUseDefaultPath";
     }
 }
\ No newline at end of file
