@@ -24,6 +24,12 @@ namespace HandBrakeWPF.Utilities
                        new InterfaceLanguage(null, Resources.Language_UseSystem),
                        new InterfaceLanguage("en", "English"),
                        new InterfaceLanguage("de", "German"),
+                       new InterfaceLanguage("zh", "Chinese"),
+                       new InterfaceLanguage("fr", "French"),
+                       new InterfaceLanguage("ru", "Russian"),
+                       new InterfaceLanguage("es", "Spanish"),
+                       new InterfaceLanguage("tr", "Turkish"),
+                       new InterfaceLanguage("ko", "Korean"),
                    };
         }
 
