@@ -924,8 +924,8 @@ namespace HandBrakeWPF.ViewModels
                 Height = this.Height,
                 ItuPar = false,
                 Modulus = this.SelectedModulus,
-                ParW = this.ParWidth,
-                ParH = this.ParHeight,
+                ParW = this.SelectedAnamorphicMode == Anamorphic.None ? 1 : this.ParWidth,
+                ParH = this.SelectedAnamorphicMode == Anamorphic.None ? 1 : this.ParHeight,
                 MaxWidth = this.MaxWidth,
                 MaxHeight = this.MaxHeight,
                 KeepDisplayAspect = this.MaintainAspectRatio,
