@@ -305,7 +305,7 @@ namespace HandBrakeWPF.ViewModels
         public void Clear()
         {
             MessageBoxResult result = this.errorService.ShowMessageBox(
-                Resources.QueueViewModel_ClearQueueConfrimation, Resources.Confirm, MessageBoxButton.YesNo, MessageBoxImage.Warning);
+                Resources.QueueViewModel_ClearQueueConfrimation, Resources.Confirm, MessageBoxButton.YesNo, MessageBoxImage.Question);
             if (result == MessageBoxResult.Yes)
             {
                 this.queueProcessor.Clear();
@@ -399,7 +399,7 @@ namespace HandBrakeWPF.ViewModels
                 return;
             }
 
-            List<QueueTask> tasksToRemove = this.SelectedItems.ToList();
+            List<QueueTask> tasksToRemove = this.SelectedItems.OrderBy(s => s.Status).ToList();
             foreach (QueueTask job in tasksToRemove)
             {
                 this.RemoveJob(job);
@@ -459,14 +459,7 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         public void RetryJob(QueueTask task)
         {
-            if (task == null)
-            {
-                return;
-            }
-
-            task.Status = QueueItemStatus.Waiting;
-            task.Statistics.Reset();
-            this.queueProcessor.BackupQueue(null);
+            this.queueProcessor.RetryJob(task);
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.NotifyOfPropertyChange(() => this.CanRetryJob);
         }
@@ -487,8 +480,11 @@ namespace HandBrakeWPF.ViewModels
             if (firstOrDefault != null && !DriveUtilities.HasMinimumDiskSpace(firstOrDefault.Task.Destination,
                     this.userSettingService.GetUserSetting<long>(UserSettingConstants.PauseQueueOnLowDiskspaceLevel)))
             {
-                this.errorService.ShowMessageBox(Resources.Main_LowDiskspace, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
-                return;
+                MessageBoxResult result = this.errorService.ShowMessageBox(Resources.Main_LowDiskspace, Resources.Warning, MessageBoxButton.YesNo, MessageBoxImage.Warning);
+                if (result == MessageBoxResult.No)
+                {
+                    return;
+                }
             }
 
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
@@ -787,7 +783,6 @@ namespace HandBrakeWPF.ViewModels
                             string logContent = logReader.ReadToEnd();
                             this.ActivityLog = logContent;
                         }
-
                     }
                     else
                     {
@@ -819,14 +814,17 @@ namespace HandBrakeWPF.ViewModels
             {
                 this.IntermediateProgress = false;
 
+                string totalHrsLeft = e.EstimatedTimeLeft.Days >= 1 ? string.Format(@"{0:d\:hh\:mm\:ss}", e.EstimatedTimeLeft) : string.Format(@"{0:hh\:mm\:ss}", e.EstimatedTimeLeft);
+                string elapsedTimeHrs = e.ElapsedTime.Days >= 1 ? string.Format(@"{0:d\:hh\:mm\:ss}", e.ElapsedTime) : string.Format(@"{0:hh\:mm\:ss}", e.ElapsedTime);
+
                 if (e.IsSubtitleScan)
                 {
                     this.JobStatus = string.Format(Resources.MainViewModel_EncodeStatusChanged_SubScan_StatusLabel,
                         e.Task,
                         e.TaskCount,
                         e.PercentComplete,
-                        e.EstimatedTimeLeft,
-                        e.ElapsedTime,
+                        totalHrsLeft,
+                        elapsedTimeHrs,
                         null);
 
                     this.ProgressValue = e.PercentComplete;
@@ -850,8 +848,8 @@ namespace HandBrakeWPF.ViewModels
                             e.PercentComplete,
                             e.CurrentFrameRate,
                             e.AverageFrameRate,
-                            e.EstimatedTimeLeft,
-                            e.ElapsedTime,
+                            totalHrsLeft,
+                            elapsedTimeHrs,
                             null);
                     this.ProgressValue = e.PercentComplete;
                 }
