@@ -228,6 +228,7 @@ namespace HandBrakeWPF.ViewModels
                     this.NotifyOfPropertyChange(() => this.SelectedOutputFormat);
                     this.NotifyOfPropertyChange(() => this.Task.OutputFormat);
                     this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
+                    this.NotifyOfPropertyChange(() => this.IsIpodAtomVisible);
                     this.SetExtension(string.Format(".{0}", this.Task.OutputFormat.ToString().ToLower()));
                     this.UpdateDisplayedInfo(); // output format may coreced to another due to container incompatibility
 
@@ -248,6 +249,19 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool IsIpodAtomVisible
+        {
+            get
+            {
+                if (this.task == null)
+                {
+                    return false;
+                }
+
+                return this.SelectedOutputFormat == OutputFormat.Mp4 && VideoEncoderHelpers.IsH264(this.task.VideoEncoder);
+            }
+        }
+
         /// <summary>
         /// Optimise MP4 Checkbox
         /// </summary>
@@ -278,6 +292,7 @@ namespace HandBrakeWPF.ViewModels
             {
                 return this.Task?.IPod5GSupport ?? false;
             }
+
             set
             {
                 if (value == this.Task.IPod5GSupport)
@@ -334,7 +349,8 @@ namespace HandBrakeWPF.ViewModels
 
             this.NotifyOfPropertyChange(() => this.SelectedOutputFormat);
             this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
- 
+            this.NotifyOfPropertyChange(() => this.IsIpodAtomVisible);
+
             this.NotifyOfPropertyChange(() => this.OptimizeMP4);
             this.NotifyOfPropertyChange(() => this.IPod5GSupport);
             this.NotifyOfPropertyChange(() => this.AlignAVStart);
@@ -478,7 +494,13 @@ namespace HandBrakeWPF.ViewModels
                 this.AlignAVStart = false;
             }
 
+            if (!VideoEncoderHelpers.IsH264(this.task.VideoEncoder))
+            {
+                this.IPod5GSupport = false;
+            }
+
             this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
+            this.NotifyOfPropertyChange(() => this.IsIpodAtomVisible);
 
             // Update The browse file extension display
             if (Path.HasExtension(newExtension))
@@ -499,7 +521,10 @@ namespace HandBrakeWPF.ViewModels
             }
 
             // Dimension Section
-            this.VideoTrackInfo = string.Format("{0}, {1} FPS {2}", EnumHelper<VideoEncoder>.GetDisplay(this.Task.VideoEncoder), this.Task.Framerate, this.Task.FramerateMode);
+            this.VideoTrackInfo = this.Task.Framerate == null 
+                                      ? string.Format("{0}, {1} FPS {2}", EnumHelper<VideoEncoder>.GetDisplay(this.Task.VideoEncoder), Resources.SummaryView_SameAsSource, this.Task.FramerateMode) 
+                                      : string.Format("{0}, {1} FPS {2}", EnumHelper<VideoEncoder>.GetDisplay(this.Task.VideoEncoder), this.Task.Framerate, this.Task.FramerateMode);
+            
             this.NotifyOfPropertyChange(() => this.VideoTrackInfo);
 
             this.AudioTrackInfo = this.GetAudioDescription();
@@ -526,6 +551,8 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.PreviewInfo);
 
             this.ShowPreview = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowPreviewOnSummaryTab);
+
+            this.NotifyOfPropertyChange(() => this.IsIpodAtomVisible);
         }
 
         private string GetFilterDescription()
